@@ -1,8 +1,10 @@
 package feedreader
 
 import (
+	"crypto/tls"
 	"fmt"
 	"html"
+	"net/http"
 	"regexp"
 	"sort"
 	"strings"
@@ -53,37 +55,31 @@ func rotateShowType(showtype ShowType) ShowType {
 	return returnValue
 }
 
-func getShowText(feedItem *FeedItem, showType ShowType) string {
-	if feedItem == nil {
-		return ""
-	}
-
-	space := regexp.MustCompile(`\s+`)
-	title := space.ReplaceAllString(feedItem.item.Title, " ")
-	if feedItem.sourceTitle != "" {
-		title = "[" + feedItem.sourceTitle + "] " + space.ReplaceAllString(feedItem.item.Title, " ")
-	}
-
-	// Convert any escaped characters to their character representation
-	title = html.UnescapeString(title)
-
-	switch showType {
-	case SHOW_LINK:
-		return feedItem.item.Link
-	case SHOW_CONTENT:
-		text, _ := html2text.FromString(feedItem.item.Content, html2text.Options{PrettyTables: true})
-		return strings.TrimSpace(title + "\n" + strings.TrimSpace(text))
-	default:
-		return title
-	}
-}
-
 // NewWidget creates a new instance of a widget
 func NewWidget(tviewApp *tview.Application, redrawChan chan bool, pages *tview.Pages, settings *Settings) *Widget {
+	parser := gofeed.NewParser()
+	if settings.disableHTTP2 {
+		// If HTTP/2 is disabled, we override the parser client
+		// with a client using a simple HTTP transport which
+		// removes the client's default behavior of first
+		// trying HTTP/2 before downgrading to older protocol
+		// versions.
+		parser.Client = &http.Client{
+			Transport: &http.Transport{
+				TLSClientConfig: &tls.Config{
+					MinVersion: tls.VersionTLS12,
+					MaxVersion: tls.VersionTLS13,
+				},
+			},
+		}
+	}
+
+	parser.UserAgent = settings.userAgent
+
 	widget := &Widget{
 		ScrollableWidget: view.NewScrollableWidget(tviewApp, redrawChan, pages, settings.Common),
 
-		parser:   gofeed.NewParser(),
+		parser:   parser,
 		settings: settings,
 		showType: SHOW_TITLE,
 	}
@@ -98,7 +94,7 @@ func NewWidget(tviewApp *tview.Application, redrawChan chan bool, pages *tview.P
 
 // Fetch retrieves RSS and Atom feed data
 func (widget *Widget) Fetch(feedURLs []string) ([]*FeedItem, error) {
-	data := []*FeedItem{}
+	var data []*FeedItem
 
 	for _, feedURL := range feedURLs {
 		feedItems, err := widget.fetchForFeed(feedURL)
@@ -143,12 +139,12 @@ func (widget *Widget) fetchForFeed(feedURL string) ([]*FeedItem, error) {
 		err  error
 	)
 	if auth, isPrivateRSS := widget.settings.credentials[feedURL]; isPrivateRSS {
-		fp := gofeed.NewParser()
-		fp.AuthConfig = &gofeed.Auth{
+		widget.parser.AuthConfig = &gofeed.Auth{
 			Username: auth.username,
 			Password: auth.password,
 		}
-		feed, err = fp.ParseURL(feedURL)
+		feed, err = widget.parser.ParseURL(feedURL)
+		widget.parser.AuthConfig = nil
 	} else {
 		feed, err = widget.parser.ParseURL(feedURL)
 	}
@@ -157,7 +153,7 @@ func (widget *Widget) fetchForFeed(feedURL string) ([]*FeedItem, error) {
 		return nil, err
 	}
 
-	feedItems := []*FeedItem{}
+	var feedItems []*FeedItem
 
 	for idx, gofeedItem := range feed.Items {
 		if widget.settings.feedLimit >= 1 && idx >= widget.settings.feedLimit {
@@ -200,7 +196,7 @@ func (widget *Widget) content() (string, string, bool) {
 			}
 		}
 
-		displayText := getShowText(feedItem, widget.showType)
+		displayText := widget.getShowText(feedItem, rowColor)
 
 		row := fmt.Sprintf(
 			"[%s]%2d. %s[white]",
@@ -215,6 +211,37 @@ func (widget *Widget) content() (string, string, bool) {
 	return title, str, false
 }
 
+func (widget *Widget) getShowText(feedItem *FeedItem, rowColor string) string {
+	if feedItem == nil {
+		return ""
+	}
+
+	space := regexp.MustCompile(`\s+`)
+	source := ""
+	publishDate := ""
+	title := space.ReplaceAllString(feedItem.item.Title, " ")
+
+	if widget.settings.showSource && feedItem.sourceTitle != "" {
+		source = "[" + widget.settings.colors.source + "]" + feedItem.sourceTitle + " "
+	}
+	if widget.settings.showPublishDate && feedItem.item.Published != "" {
+		publishDate = "[" + widget.settings.colors.publishDate + "]" + feedItem.item.PublishedParsed.Format(widget.settings.dateFormat) + " "
+	}
+
+	// Convert any escaped characters to their character representation
+	title = html.UnescapeString(source + publishDate + "[" + rowColor + "]" + title)
+
+	switch widget.showType {
+	case SHOW_LINK:
+		return feedItem.item.Link
+	case SHOW_CONTENT:
+		text, _ := html2text.FromString(feedItem.item.Content, html2text.Options{PrettyTables: true})
+		return strings.TrimSpace(title + "\n" + strings.TrimSpace(text))
+	default:
+		return title
+	}
+}
+
 // feedItems are sorted by published date
 func (widget *Widget) sort(feedItems []*FeedItem) []*FeedItem {
 	sort.Slice(feedItems, func(i, j int) bool {
