@@ -61,7 +61,7 @@ func authHandler(w http.ResponseWriter, r *http.Request) {
 }
 
 // NewWidget creates a new widget for WTF
-func NewWidget(tviewApp *tview.Application, pages *tview.Pages, settings *Settings) *Widget {
+func NewWidget(tviewApp *tview.Application, redrawChan chan bool, pages *tview.Pages, settings *Settings) *Widget {
 	redirectURI = "http://localhost:" + settings.callbackPort + "/callback"
 
 	auth = spotify.NewAuthenticator(redirectURI, spotify.ScopeUserReadCurrentlyPlaying, spotify.ScopeUserReadPlaybackState, spotify.ScopeUserModifyPlaybackState)
@@ -72,7 +72,7 @@ func NewWidget(tviewApp *tview.Application, pages *tview.Pages, settings *Settin
 	var playerState *spotify.PlayerState
 
 	widget := Widget{
-		TextWidget: view.NewTextWidget(tviewApp, pages, settings.Common),
+		TextWidget: view.NewTextWidget(tviewApp, redrawChan, pages, settings.Common),
 
 		Info: Info{},
 
