@@ -1,6 +1,6 @@
 package twitch
 
-import "github.com/gdamore/tcell"
+import "github.com/gdamore/tcell/v2"
 
 func (widget *Widget) initializeKeyboardControls() {
 	widget.InitializeHelpTextKeyboardControl(widget.ShowHelp)
@@ -9,6 +9,7 @@ func (widget *Widget) initializeKeyboardControls() {
 	widget.SetKeyboardChar("j", widget.Next, "Select next item")
 	widget.SetKeyboardChar("k", widget.Prev, "Select previous item")
 	widget.SetKeyboardChar("o", widget.openTwitch, "Open target URL in browser")
+	widget.SetKeyboardChar("s", widget.openStreamlink, "Open target stream via streamlink (github.com/streamlink/streamlink)")
 
 	widget.SetKeyboardKey(tcell.KeyDown, widget.Next, "Select next item")
 	widget.SetKeyboardKey(tcell.KeyUp, widget.Prev, "Select previous item")
