@@ -25,11 +25,13 @@ type Base struct {
 	refreshing      bool
 	tviewApp        *tview.Application
 	view            *tview.TextView
+
+	RedrawChan chan bool
 }
 
 // NewBase creates and returns an instance of the Base module, the lowest-level
 // primitive module from which all others are derived
-func NewBase(tviewApp *tview.Application, pages *tview.Pages, commonSettings *cfg.Common) *Base {
+func NewBase(tviewApp *tview.Application, redrawChan chan bool, pages *tview.Pages, commonSettings *cfg.Common) *Base {
 	base := &Base{
 		commonSettings: commonSettings,
 
@@ -44,6 +46,8 @@ func NewBase(tviewApp *tview.Application, pages *tview.Pages, commonSettings *cf
 		refreshInterval: commonSettings.RefreshInterval,
 		refreshing:      false,
 		tviewApp:        tviewApp,
+
+		RedrawChan: redrawChan,
 	}
 
 	return base
@@ -160,9 +164,8 @@ func (base *Base) ShowHelp() {
 	base.pages.AddPage("help", modal, false, true)
 	base.tviewApp.SetFocus(modal)
 
-	base.tviewApp.QueueUpdate(func() {
-		base.tviewApp.Draw()
-	})
+	// Tell the app to force redraw the screen
+	base.RedrawChan <- true
 }
 
 func (base *Base) Stop() {
